@@ -62,11 +62,7 @@ class DjangoCacheNotifier(BaseNotifier):
         self.cache_key_prefix = cache_key_prefix
         self.metrics_lifespan = metrics_lifespan
 
-        # clear cache keys during init to avoid all sort of incompatibilities
-        cache = self.get_cache()
-        cache.delete(self.get_last_value_cache_key())
-        cache.delete(self.get_values_cache_key())
-
+        self._first_notify = True
         self.initialized = True
 
     def get_cache(self) -> BaseCache:
@@ -86,6 +82,13 @@ class DjangoCacheNotifier(BaseNotifier):
         if not self.initialized:
             return
 
+        if self._first_notify:
+            # clear cache keys during init to avoid all sort of incompatibilities
+            cache = self.get_cache()
+            cache.delete(self.get_last_value_cache_key())
+            cache.delete(self.get_values_cache_key())
+            self._first_notify = False
+
         threading.Thread(
             target=notify_django_cache_time_queue,
             args=[
