@@ -1,5 +1,6 @@
 import logging
 from datetime import datetime, timedelta
+from typing import Iterable
 
 from request_time_tracker.notifiers.base import BaseNotifier
 
@@ -12,11 +13,17 @@ class BaseQueueTimeTracker:
         send_stats_every_seconds: int = 10,
         queue_time_header_name: str = None,
         notifier: BaseNotifier = None,
+        notifiers: Iterable[BaseNotifier] = None,
     ):
         self.parent_application = parent_application
         self.send_stats_every_seconds = send_stats_every_seconds
         self.queue_time_header_name = queue_time_header_name
-        self.notifier = notifier
+
+        self.notifiers = []
+        if notifier:
+            self.notifiers.append(notifier)
+        if notifiers:
+            self.notifiers.extend(notifiers)
 
     def check_cooldown(self) -> bool:
         """
@@ -46,6 +53,7 @@ class BaseQueueTimeTracker:
         time_spent_in_queue = self.get_time_spent_in_queue(environ)
         if time_spent_in_queue and self.check_cooldown():
             self.refresh_cooldown()
-            self.notifier.notify_time_spent(time_spent_in_queue)
+            for notifier in self.notifiers:
+                notifier.notify_time_spent(time_spent_in_queue)
 
         return self.parent_application(environ, start_response)
